# Security Policy

## Supported Versions

| Version | Supported          |
| ------- | ------------------ |
| 2.0.0   | :white_check_mark: |

## Reporting a Vulnerability

This project is using private vulnerability reporting. To report vulnerabilities, please go to https://github.com/bp4151/cvss-rescore/security/advisories and click the 
New Draft Security Advisory to notify the maintainers. 
